CharacterCard

Enum CharacterCard 

#[non_exhaustive]
pub enum CharacterCard {
Show 27 variants KamisatoAyaka, Chongyun, Diona, Ganyu, Kaeya, Barbara, Mona, Xingqiu, Cyno, Fischl, Keqing, Razor, Ningguang, Noelle, Collei, Jean, Sucrose, Bennett, Diluc, Xiangling, Yoimiya, MirrorMaiden, RhodeiaOfLoch, StonehideLawachurl, JadeplumeTerrorshroom, MaguuKenki, FatuiPyroAgent,
}

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


KamisatoAyaka



Chongyun



Diona



Ganyu



Kaeya



Barbara



Mona



Xingqiu



Cyno



Fischl



Keqing



Razor



Ningguang



Noelle



Collei



Jean



Sucrose



Bennett



Diluc



Xiangling



Yoimiya



MirrorMaiden



RhodeiaOfLoch



StonehideLawachurl



JadeplumeTerrorshroom



MaguuKenki



FatuiPyroAgent

Implementations

Source

impl CharacterCard

pub fn name(&self) -> &'static str

pub fn element(&self) -> Element

pub fn weapon(&self) -> Option<WeaponType>

The weapon type this character can hold

Returns None for characters listed as “Other Weapon”

pub fn faction(&self) -> Faction