Normal types of event cards, with no subtypes, might rename this variant and subtype later
Elemental Resonance cards
23
24
25
26
27
28
29
pub fn name(&self) -> &'static str {
match self {
Self::Equipment(card) => card.name(),
Self::Support(card) => card.name(),
Self::Event(card) => card.name(),
}
}
Returns Some(price) in Lucky Coins to buy the given card in the shop.
Cards not sold in the shop (such as TossUp) return None
37
38
39
40
41
42
43
pub fn shop_price(&self) -> Option<Price> {
match self {
Self::Equipment(card) => card.shop_price(),
Self::Support(card) => card.shop_price(),
Self::Event(card) => card.shop_price(),
}
}
45
46
47
48
49
50
51
pub fn cost(&self) -> CardCost {
match self {
Self::Equipment(card) => card.cost(),
Self::Support(card) => card.cost(),
Self::Event(card) => card.cost(),
}
}
Performs copy-assignment from
source.
Read more
Formats the value using the given formatter.
Read more
This method tests for self and other values to be equal, and is used
by ==.
This method tests for !=. The default implementation is almost always
sufficient, and should not be overridden without very good reason.
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The resulting type after obtaining ownership.
Creates owned data from borrowed data, usually by cloning.
Read more
Uses borrowed data to replace owned data, usually by cloning.
Read more
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.