CardCost

Struct CardCost 

pub struct CardCost { /* private fields */ }

Implementations

Source

impl CardCost

pub fn dice_type(&self) -> DiceCost

Retrieves which type of dice is required to play the given card

pub fn amount(&self) -> u8

The amount of dice required to play the given card

pub fn energy(&self) -> u8

The amount of character energy required to play this card

Most cards don’t require energy, which means zero