Enum genius_invokation::WeaponCard
source · #[non_exhaustive]
pub enum WeaponCard {
Show 15 variants
MagicGuide,
SacrificialFragments,
SkywardAtlas,
RavenBow,
SacrificialBow,
SkywardHarp,
WhiteIronGreatsword,
SacrificialGreatsword,
WolfsGravestone,
WhiteTassel,
LithicSpear,
SkywardSpine,
TravelersHandySword,
SacrificialSword,
AquilaFavonia,
}Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
MagicGuide
SacrificialFragments
SkywardAtlas
RavenBow
SacrificialBow
SkywardHarp
WhiteIronGreatsword
SacrificialGreatsword
WolfsGravestone
WhiteTassel
LithicSpear
SkywardSpine
TravelersHandySword
SacrificialSword
AquilaFavonia
Implementations
sourceimpl WeaponCard
impl WeaponCard
sourcepub fn shop_price(&self) -> u16
pub fn shop_price(&self) -> u16
sourcepub fn subtype(&self) -> Option<WeaponType>
pub fn subtype(&self) -> Option<WeaponType>
Retrieves the weapon type for this card
Currently, this method never returns None, but since some character cards have the
“Other Weapons” subtype, this could potentially mean there will be cards in the future
that don’t fit into any of the weapon types, which would return None for this method